/**
 * A menu button.
 * @param {GenericMenuButton} gen Generic map button for base functionality. 
 */
function MapMenuButton(gen) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = "amapmenubutton";
    var selected = false;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Returns the subtitle of this button.
     * @returns {string} The subtitle of this button.
     */
    function getSubtitle() {
        return "aMap";
    }

    /**
     * Returns the instructional content of this button.
     * @returns {string} The instructional content of this button.
     */
    function getContent() {
        var content = ` aMap is a handy feature that allows you to view scene trees, which are overviews of all the choices you can make in the game.
                        aMap contains a lot of spoilers.
                        Usage of aMap is considered cheating.
                        Use it only if you want to make sure you've found every single path available.
                        Note that certain secret paths may be omitted from aMap.
                        Click the aMap button again to open aMap in a new tab.`;
        return global.parser.parse(content);
    }

    /**
     * Returns the URL to route to when this button is clicked twice.
     * @returns {string} The URL to route to when this button is clicked twice.
     */
    function getUrl() {
        return "map/index.html";
    }

    /**
     * Stops event propagation.
     * @param {event} event The event to stop propagation of.
     */
    function stopProp(event) {
        event.stopPropagation();
    }

    /**
     * Opens a new tab with the button's specified URL.
     * @param {event} event The click event.
     */
    function clickedTwice(event) {
        that.unset();
        gen.open(getUrl());
    }

    /**
     * Onclick function.
     * @param {event} event The click event.
     */
    function clicked(event) {
        if (selected) {
            clickedTwice(event);
        } else {
            gen.set(id, getSubtitle(), getContent());
            selected = true;
        }
        stopProp(event);
    }

    /*
     * Registers listeners for this button.
     */
    function registerListeners() {
        $("#" + id).click(clicked);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes the button.
     */
    this.init = function () {
        registerListeners();
    };

    /**
     * Unsets the button.
     */
    this.unset = function () {
        if (!selected) {
            return;
        }
        selected = false;
        gen.unset(id);
    };
}
