/**
 * Controller for the Forest scene.
 * @param {string} sceneId The id of the scene.
 */
function ForestController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.intro = new ForestIntroductionController(id);
    this.home = new ForestHomeController(id);
    this.woods = new ForestWoodsController(id);
    this.bandit = new ForestBanditController(id);
    this.unknown = new ForestUnknownController(id);

    this.homeSceneName = "Home";
    this.enslaveSceneName = "CaravanConfinement";
    this.enslaveFolder = "Enslavement";
    this.enslaveReady = true;

    this.misc = new MiscController(id);

    this.hide = new ChoiceController(id, "hide");
    this.tree = new ChangeController(id, "tree", function change() {
        global.kobold.status.physical.decrease(5, "Bee sting");
        global.kobold.status.stamina.decrease(10, "Tree climbing");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Got stung", "Health", -5),
            new Change("Tree climbing", "Stamina", -10)
        ]);
    });
    this.treeFail = new ChangeController(id, "treeFail", function change() {
        global.kobold.status.mental.decrease(10, "Panicking");
        global.kobold.status.stamina.decrease(10, "Attempted climbing");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Panic", "Sanity", -10),
            new Change("Attempted climbing", "Stamina", -10)
        ]);
    });
    this.bush = new ChangeController(id, "bush", function change() {
        global.kobold.status.mental.decrease(10, "Panicking");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Panic", "Sanity", -10)
        ]);
    });
    this.run = new ChangeController(id, "run", function change() {
        global.kobold.status.mental.increase(10, "Fortune");
        global.kobold.status.mental.decrease(5, "Misfortune");
        global.kobold.status.stamina.decrease(25, "Intensive running");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Fortune", "Sanity", +10),
            new Change("Misfortune", "Sanity", -5),
            new Change("Intensive running", "Stamina", -25)
        ]);
    });

    this.runFail = new ChangeController(id, "runFail", function change() {
        global.kobold.status.physical.decrease(15, "Getting choked");
        global.kobold.status.mental.decrease(20, "Imminent rape");
        global.kobold.inventory.equipment.strip(SlotEnum.BRA);
        global.kobold.inventory.equipment.strip(SlotEnum.PANTS);
        global.kobold.inventory.equipment.strip(SlotEnum.UNDERWEAR);
        global.kobold.inventory.equipment.strip(SlotEnum.WEAPON);
        global.kobold.inventory.coins -= that.misc.gold();
    }, function changeNote() {
        var weapon = that.misc.weapon();
        var bra = that.misc.bra();
        var pants = that.misc.pants();
        var underwear = that.misc.underwear();
        var changeArray =
                [new Change("Hit branch", "Health", -10),
                    new Change("Being choked", "Health", -5),
                    new Change("Caught", "Sanity", -10),
                    new Change("Imminent rape", "Sanity", -10),
                    new Change("Money taken", "Gold", -that.misc.gold())];
        if (weapon) {
            changeArray.push(new Change("Lost weapon", global.kobold.inventory.createItemWithTooltip(weapon, true), -1));
        }
        if (bra) {
            changeArray.push(new Change("Torn bra", global.kobold.inventory.createItemWithTooltip(bra, true), -1));
        }
        if (pants) {
            changeArray.push(new Change("Ripped pants", global.kobold.inventory.createItemWithTooltip(pants, true), -1));
        }
        if (underwear) {
            changeArray.push(new Change("Ripped underwear", global.kobold.inventory.createItemWithTooltip(underwear, true), -1));
        }
        return global.ui.change.buildNotification(changeArray);
    });

    this.struggle = new ChoiceController(id, "runFailStruggle");

    this.preContinue = new ContinueController(id, "preContinue");

    this.treeThrow = new ChangeController(id, "treeThrow", function change() {
        global.kobold.status.physical.decrease(10, "Bee stings");
        global.kobold.status.mental.increase(10, "Outsmarting pursuers");
        global.kobold.status.stamina.decrease(15, "Running away");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Multiple stings", "Health", -10),
            new Change("Outsmarted pursuers", "Sanity", +10),
            new Change("Jumped down", "Stamina", -5),
            new Change("Ran away", "Stamina", -10)
        ]);
    });

    this.treeWeather = new ChangeController(id, "treeWeather", function change() {
        global.kobold.status.physical.decrease(50, "Hellish pain");
        global.kobold.status.mental.decrease(20, "Near death experience");
        global.kobold.stats.decreaseStat(StatsEnum.STRENGTH, 1);
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Massive amounts of beestings", "Health", -30),
            new Change("Fell down tree", "Health", -20),
            new Change("Near death experience", "Sanity", -10),
            new Change("Traumatized", "Sanity", -10),
            new Change("Lasting effects", "Strength", -1)
        ]);
    });

    this.surrenderRock = new ChangeController(id, "surrenderRock", function change() {
        var rock = that.intro.getItemChoice() === ItemEnum.ROCK;
        global.kobold.status.physical.decrease(20, `${rock ? "Rock" : "Stick"} insertion`);
        global.kobold.status.mental.decrease(35, `${rock ? "Rock" : "Stick"} insertion`);
        global.kobold.status.exertion.increase(15, `${rock ? "Rock" : "Stick"} insertion`);
        global.kobold.inventory.coins -= that.misc.gold();
        if (that.misc.cunt()) {
            global.kobold.body.vaginalVirgin = false;
        } else {
            global.kobold.body.cockslitVirgin = false;
        }
    }, function changeNote() {
        var rock = that.intro.getItemChoice() === ItemEnum.ROCK;
        return global.ui.change.buildNotification([
            new Change(`${rock ? "Rock" : "Stick"} insertion`, "Health", -20),
            new Change(`${rock ? "Rock" : "Stick"} insertion`, "Sanity", -35),
            new Change(`${rock ? "Rock" : "Stick"} insertion`, "Sexual exhaustion", +15, true),
            new Change("Money taken", "Gold", -that.misc.gold())
        ]);
    });

    this.surrenderSpank = new ChangeController(id, "surrenderSpank", function change() {
        global.kobold.status.physical.decrease(10, "Firmly spanked");
        global.kobold.status.mental.decrease(30, "Extreme humiliation");
        global.kobold.status.exertion.increase(5, "Hurting rear");
        global.kobold.inventory.coins -= that.misc.gold();
        global.kobold.stats.decreaseStat(StatsEnum.ENDURANCE, 1);
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Spanked", "Health", -10),
            new Change("Humiliated", "Sanity", -30),
            new Change("Rear hurts", "Sexual exhaustion", +5, true),
            new Change("Money taken", "Gold", -that.misc.gold()),
            new Change("Sensitive behind", "Endurance", -1)
        ]);
    });

    this.hideStick = new ChangeController(id, "hideStick", function change() {
        global.kobold.status.mental.increase(10, "Outsmarting pursuers");
        global.kobold.inventory.equipment.strip(SlotEnum.WEAPON);
        global.kobold.stats.increaseStat(StatsEnum.INTELLIGENCE, 1);
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Outsmarted pursuers", "Sanity", +10),
            new Change("Lost stick", global.kobold.inventory.createItemWithTooltip(that.misc.weapon(), true), -1),
            new Change("Smart move", "Intelligence", +1)
        ]);
    });

    this.runSucceed = new ChangeController(id, "runSucceed", function change() {
        global.kobold.status.mental.increase(10, "Escaped pursuers");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Escaped pursuers", "Sanity", +10)
        ]);
    });

    this.beg = new ChangeController(id, "beg", function change() {
        global.kobold.status.mental.increase(10, "Rape avoided");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Rape avoided", "Sanity", +25),
            new Change("Captured", "Sanity", -15)
        ]);
    });

    this.hate = new ChangeController(id, "hate", function change() {
        if (that.misc.cunt()) {
            global.kobold.body.vaginalVirgin = false;
        } else {
            global.kobold.body.analVirgin = false;
        }
        global.kobold.status.physical.decrease(5, "Thoroughly stretched");
        global.kobold.status.mental.decrease(20, "Raped");
        global.kobold.status.exertion.increase(40, "Raped by an anthro wolf");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Thoroughly stretched", "Health", -5),
            new Change("Raped", "Sanity", -20),
            new Change("Rape", "Sexual exhaustion", +40, true)
        ]);
    });

    this.enjoy = new ChangeController(id, "enjoy", function change() {
        if (that.misc.cunt()) {
            global.kobold.body.vaginalVirgin = false;
        } else {
            global.kobold.body.analVirgin = false;
        }
        global.kobold.status.physical.decrease(5, "Thoroughly stretched");
        global.kobold.status.mental.decrease(10, "Didn't get the knot");
        global.kobold.status.stamina.decrease(10, "Intense sex");
        global.kobold.status.exertion.increase(30, "Sex with an anthro wolf");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Thoroughly stretched", "Health", -5),
            new Change("Reached climax", "Sanity", +5),
            new Change("Got off to rape", "Sanity", -10),
            new Change("Didn't get the knot", "Sanity", -5),
            new Change("Intense sex", "Stamina", -10),
            new Change("Rough wolf fucking", "Sexual exhaustion", +30, true)
        ]);
    });

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
}


