/**
 * Hide section of the woods.
 * @param {ForestController} controller The Forest controller.
 */
function ForestWoodsRun(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstChoice = new ForestWoodsRunSlide(ctrl);
    var secondChoice = new ForestWoodsRunBreakthrough(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You won't be getting caught today.
                            No matter how bad things may look, this is still [b]your[/b] forest.
                            They may have tracked you this far, but having lived here your entire life, you know a thing or two that they don't.
                            This isn't your first time getting chased around the woods.
                            And you [b]refuse[/b] to let it be your last.
                        [/p]
                        [p]
                            There are certain places where [i]larger[/i] species simply [i]can't reach[/i].
                            Parts of the forest where trees are packed so closely together, they form a [b]barrier[/b],
                            impassable to anyone bigger than a child...[i]or a kobold[/i].
                            One of these sections is pretty close to where you are.
                            If you can make it there before your pursuers catch up to you,
                            you [i]might[/i] have a [i]chance[/i] at escaping their grasping clutches.
                        [/p]
                        [p]
                            You begin to [b]run[/b] towards what you believe to be your one shot at salvation.
                            Looking behind you, you can see the clear outlines of a pair of large men in the distance.
                            They're rapidly gaining on you, their sheer size allowing them to easily outrun you.
                            You pick up the pace, but it's still not enough.
                            In less than a minute since the chase began, they manage to get close enough for you to identify them.
                            An anthromorphic wolf and a human, with a leashed feral dog leading the latter in the chase.
                            The rabid spittle fluttering from its toothy maw leaves behind a disgusting trail, undoubtedly born from mindless [b]anger[/b].
                        [/p]
                        [p]
                            It's just a little further up ahead.
                            Your pursuers are getting drawing near.
                            You can't let them get any closer.
                            Pushing your body to its very limits, you burst into a sprint.
                            Still it's not enough.
                            The human and his dog are [b]right[/b] behind you, the feral's teeth on the [b]verge[/b] of sinking into your scaly tail.
                        [/p]
                        [p]
                            Suddenly, out of nowhere, a startled deer [b]hops[/b] in front of you, scaring you to the point of nearly costing you your balance.
                            You fear the small slowdown may have cost you your very life, but casting your gaze backwards,
                            you realize the animal was a hint of [b]good fortune[/b] instead of spelling your doom.
                            The dog chasing after you loses interest in catching your scaly tail, instead bolting after the fleeing cervine.
                            Its master, unwilling to let go of the canine's leash, gets tugged to the ground by the sudden change of direction.
                        [/p]
                        [p]
                            The human loudly curses at his pet, which disappears into the woods.
                            With him and the dog both out of the picture, you might make it to safety after all!
                            The wolf, being just a little [i]too[/i] big to nimbly manoeuvre around the woods, is still quite a bit off. 
                            Unlike his human companion, though, he doesn't simply [i]give up[/i] pursuit.
                        [/p]
                        [p]
                            After half a minute more of the wearying chase, the dense formation of trees you were heading for comes into view.
                            The wooden giants together form a living wall, separated by gaps too tiny for even [i]your kind[/i] to fit through.
                            There is, however, a single small passageway leading throughout the entirety of the thicket.
                            Big enough for you, not [b]nearly[/b] large enough for [i]him[/i].
                            That is your goal.
                        [/p]
                        [p]
                            Fear fills your heart as you near the tight corridor.
                            A large, rotten branch stuck between two trees blocks the entrance to the path.
                            With the wolf gaining on you, you don't have time to try to dislodge it.
                            You're going to have to deal with this without stopping.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = ctrl.run.has() ? "disabled" : "";
        var isSelected = ctrl.run.get() === ForestWoodsRunChoice.SLIDE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width:180px;">Slide underneath</button>`;

        var tooltip = global.parser.parse(`A fancy slide through the dirt'll allow you to avoid the obstacle.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:180px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = ctrl.run.has() ? "disabled" : "";
        var isSelected = ctrl.run.get() === ForestWoodsRunChoice.BREAKTHROUGH;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Break through</button>`;

        var tooltip = global.parser.parse(`The barring branch looks old and weak. Bash through it with blunt force and momentum.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.run.set(ForestWoodsRunChoice.SLIDE);
            loadNextPart(firstChoice);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.run.set(ForestWoodsRunChoice.BREAKTHROUGH);
            loadNextPart(secondChoice);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.treeFail.get() !== ForestWoodsTreeFailChoice.RUN && ctrl.bush.get() !== ForestWoodsHideBushChoice.RUN) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.run.change();
        part += buildChoice();
        part += `</div>`;
        part += firstChoice.build();
        part += secondChoice.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.treeFail.get() !== ForestWoodsTreeFailChoice.RUN && ctrl.bush.get() !== ForestWoodsHideBushChoice.RUN) {
            return;
        }

        firstChoice.registerListeners();
        secondChoice.registerListeners();

        if (ctrl.run.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestWoodsRunChoice = {
    SLIDE: 1,
    BREAKTHROUGH: 2
};
