/**
 * The home section of the Forest scene.
 * @param {ForestController} controller The forest controller.
 * @param {ForestBandit} bandit One of the parts the kobold can go next.
 */
function ForestHome(controller, bandit) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var hideInBush = new ForestHomeHide(ctrl);
    var ignoreScream = new ForestHomeIgnore(ctrl);
    var pathSelection = new ForestHomePath(ctrl, bandit, hideInBush, ignoreScream);
    
    // PRIVATE FUNCTIONS \\     function privateFunction(){}
    
    
    // PUBLIC MEMBERS \\        this.public = "test";

    // The id of this segment.
    this.id = "forestHome";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
    
    /**
     * Builds and returns this part.
     * @param {boolean} invisible If true, will build this part invisible.
     */
    this.build = function(invisible) {
        if (!ctrl.intro.hasMadePathChoice()) {
            return "";
        }
        if (ctrl.intro.getPathChoice() !== ForestIntroductionPathChoiceEnum.HOME) {
            return "";
        }
        var home = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        home += `<div class="subtitle">Going home</div>`;
        home += pathSelection.build();
        home += hideInBush.build();
        home += ignoreScream.build();
        home += `</div>`;
        return home;
    };
    
    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function() {
        if (!ctrl.intro.hasMadePathChoice()) {
            return;
        }
        if (ctrl.intro.getPathChoice() !== ForestIntroductionPathChoiceEnum.HOME) {
            return;
        }
        pathSelection.registerListeners();
        hideInBush.registerListeners();
        ignoreScream.registerListeners();
    };
}

