/**
 * The introduction of the Forest scene.
 * @param {ForestController} controller The forest controller.
 * @param {ForestHome} home One of the parts the kobold can go next.
 * @param {ForestBridge} bridge One of the parts the kobold can go next.
 * @param {ForestWoods} woods One of the parts the kobold can go next.
 */
function ForestIntroduction(controller, home, bridge, woods) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var pathSelection = new ForestIntroductionPathSelection(ctrl, home, bridge, woods);
    var itemSelection = new ForestIntroductionItemSelection(ctrl, pathSelection);
    var recovering = new ForestIntroductionRecovering(ctrl, itemSelection);
    
    // PRIVATE FUNCTIONS \\     function privateFunction(){}
    
    
    // PUBLIC MEMBERS \\        this.public = "test";

    // The id of this segment.
    this.id = "forestIntroduction";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
    
    /**
     * Builds and returns this part.
     */
    this.build = function() {
        var introduction = `<div id="${that.id}">`;
        introduction += recovering.build();
        introduction += itemSelection.build();
        introduction += pathSelection.build();
        introduction += `</div>`;
        return introduction;
    };
    
    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function() {
        recovering.registerListeners();
        itemSelection.registerListeners();
        pathSelection.registerListeners();
    };
}

