/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnLootUpstairs(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "notBarnLootUpstairsCButton";
    
    var next = new NotBarnLootUpstairsContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var dead = global.kobold.history.shared.cassidy.dead;
        var toReturn = `[p]
                            You sprint towards the stairs, and ascend them with haste.
                            The second floor hallway contains even more pictures,
                            these ones far more risqu&eacute; than the ones downstairs.
                            Naked kobolds, fornicating foxes, even some of your kind mating with vulpines.
                            While the paintings are distracting and disturbing, to say the least,
                            you force yourself to face away from them, and set your mind to the task at hand.
                        [/p]
                        [p]
                            All of the doors are closed.
                            You'll have to search each room at a time.
                            The first one you enter is a small, dusty storageroom, with nothing of value in it for you to pocket.
                            The second seems to pass as some sort of bathroom, with a fancy mirror on the wall a large wooden tub at the center.
                            Again: nothing to steal.
                        [/p]
                        [p]
                            You enter a third room.
                            Bullseye.
                            The vixen's bedroom.
                            Surely there'll be some goodies in here, right?
                            You search through both her nightstands, finding nothing but various pairs of infrequently worn panties, none of which are your size.
                            Ontop of the underwear, you find a pair of fake, fur-lined handcuffs and a small, smooth, dog-phallic-shaped piece of wood,
                            the use of which you can only [i]imagine[/i].
                        [/p]
                        [p]
                            Just as you were about to give up hope on finding anything of value whatsoever,
                            you accidentally trip over a pair of panties, landing face-first on the hard, wooden floor.
                            Recovering from the fall, your gaze wanders to the underside of the vulpine's bed,
                            where you spot a tiny coinpouch, seemingly filled to the very brim.
                            You rub your head to ease your pain, and pinch yourself to make sure you're not hallucinating.
                            Nope.
                            It's real!
                        [/p]
                        [p]
                            Just as you reach out and grab the bag, you hear a noise at the front door.
                            A voice calling out to Cassidy, trying to get her to wake up.
                            Deciding not to take any chances, you swipe the pouch and hop to your feet.
                            You consider bolting for the back door, but with an unwelcome [i]guest[/i] around,
                            the chance of being seen is too great.
                            Instead, you open one of the bedroom windows, and sneakily climb down a handily-placed vine plant encroaching upon the building.
                            Silently dropping down to the back yard, you escape the scene of the crime unnoticed.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildContinueChoice() {
        var disabled = ctrl.postnotbarnloot.has() ? "disabled" : "";
        var isSelected = ctrl.postnotbarnloot.has();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildContinueChoice();
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.postnotbarnloot.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnLootUpstairs";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.notbarnloot.get() !== NotBarnLootChoice.UPSTAIRS) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.notbarnUpstairsLootChange();
        part += buildChoice();
        part += next.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.notbarnloot.get() !== NotBarnLootChoice.UPSTAIRS) {
            return;
        }

        next.registerListeners();

        if (ctrl.postnotbarnloot.has()) {
            return;
        }

        registerContinueListener();
    };
}
