/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function BarnUnhinged(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var toUnaware = new BarnUnaware(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Frustrated, you writhe around, fighting against your restraints,
                            testing both the limits of the iron cuffs holding you in place,
                            and the patience of your [i]hostess[/i].
                            While your efforts prove to be quite fruitless, you [b]do[/b] notice something.
                            Three of the cuffs are firmly locked in place, yet the one holding your right arm seems a bit...[i]loose[/i].
                            It rattles whenever you tug your arm to the side, moving ever so slightly.
                        [/p]
                        [p]
                            As Cassidy continues to look for a single vial that [i]isn't[/i] empty,
                            you quietly begin to [i]experiment[/i] with the wobbly mechanism.
                            While the other cuffs have fallen into fastening latches, this one seems to have [i]missed[/i] its locking apparatus.
                            If you can apply [i]just[/i] the right amount of tension in the correct manner, you [b]might[/b] be able to free yourself, or at least your arm.
                        [/p]
                        [p]
                            As though your life depends on it -- which it does -- you start to twiddle the janky piece of metal around.
                            At first you try simply tugging it open, to no avail.
                            Then, you test some [i]smoother[/i], more delicate motions.
                            You come to the conclusion that shaking your arm from side to side seems to loosen the mechanism ever so slightly,
                            although you're not quite sure why.
                        [/p]
                        [p]
                            Realizing your window of opportunity is rapidly closing, an unsettling kind of nervousness springs up at the back of your mind.
                            You attempt to yank the cuff to the left, yet it doesn't budge beyond a certain point.
                            To the right, neither, proves to be the right answer.
                            Your brain is working overtime to comprehend how this thing works.
                            Then it dawns on you.
                            The solution!
                        [/p]
                        [p]
                            Instead of moving your arm one way or the other,
                            you [b]rotate[/b] the scaly appendage as best as you are able to,
                            the metal cuff being [b]lifted[/b] out of its improperly-fastened clasp.
                            It's just a little, but it's enough to allow you to [b]yank[/b] the mechanism open the rest of the way,
                            freeing your right arm through sheer brute force!
                        [/p]
                        [p]
                            With your now-free hand, you begin to pry at the other cuffs.
                            While nearly impossible to remove by whoever's trapped on the table,
                            barring any sort of malfunction as you were lucky enough to experience,
                            it seems that these restraints were made to be easily undone from the outside.
                            You hastily free the rest of your limbs, before hopping off of the table.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "barnUnhinged";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.table.get() !== BarnTableChoice.UNHINGED) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += toUnaware.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.table.get() !== BarnTableChoice.UNHINGED) {
            return;
        }

        toUnaware.registerListeners();
    };
}
