/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";

    var childFirstNext = new HamletWellSwim(ctrl);
    var childSecondNext = new HamletWellClimbUp(ctrl);
    var childThirdNext = new HamletWellHelp(ctrl);

    var firstNext = new HamletWellWalk(ctrl, childFirstNext, childSecondNext, childThirdNext);
    var secondNext = new HamletWellWater(ctrl, childFirstNext, childSecondNext, childThirdNext);
    var thirdNext = new HamletWellClimb(ctrl, childFirstNext, childSecondNext, childThirdNext);
    var fourthNext = new HamletWellRope(ctrl, childFirstNext, childSecondNext, childThirdNext);

    var firstChoice = HamletWellArrivalChoice.WALK;
    var secondChoice = HamletWellArrivalChoice.WATER;
    var thirdChoice = HamletWellArrivalChoice.CLIMB;
    var fourthChoice = HamletWellArrivalChoice.ROPE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            In an attempt to take your mind off of Seki, you turn your attention to the well.
                            It's a small, circular structure that reaches slightly above your waist.
                            The cobblestone it's made of looks pretty shabby, like it's fit to collapse any minute now.
                            Then again, judging by the ancient-looking moss clinging to the damp dirt on the northern end,
                            you figure the well's been around for a [b]very[/b] long time.
                            You probably won't look that good when you reach its age.
                        [/p]
                        [p]
                            If there's one thing humans are good at, it's building things that last.
                            From gigantic stone walls surrounding their enormous cities, to intricately engraved cathedral-windows.
                            Compared to the slums and sheds kobolds live in, even the simplest of human homes could pass for a [b]palace[/b].
                            Fit for [b]royalty[/b], if your kind actually [i]had[/i] rulership beyond petty crime lords.
                            Maybe that's why your species never learned to construct things beyond small cabins.
                            There isn't any need for big homes when everyone is [i]equally unimportant[/i].
                            Or maybe it's the other way around?
                        [/p]
                        [p]
                            You, personally, have never really built anything.
                            You kind of [i]stumbled upon[/i] the shack that you live in,
                            and you don't have need for anything but a place to rest your weary head at night.
                            You imagine building things it isn't all that easy, especially not for someone your size.
                            Even if you somehow made it through the whole [i]planning[/i] phase,
                            the sheer amount of physical work needed to build something is far too much for any one kobold to handle.
                            And good luck getting an entire team to work together for more than a couple of days.
                        [/p]
                        [p]
                            What were you thinking about again?
                            Before you started [i]daydreaming[/i]?
                            Oh right, the well.
                        [/p]
                        [p]
                            You leisurely pace a few laps around it, inspecting the old structure.
                            A rope lies coiled next to it, one end disappearing into the watering hole's pitch-blackness.
                            The irregular stones the well is made of vary heavily in size.
                            Some are as big as your fist, others are but mere pebbles.
                            They're tied together by a flimsy lime-mixture.
                            Heck, you could probably tear the entire thing apart using nothing but your claws.
                        [/p]
                        [p]
                            You somehow doubt the locals would appreciate you [i]demolishing[/i] their convenient supply of water, though.
                            Then again, the river isn't [i]that[/i] far off.
                            Those lazy farmers getting fat off their own produce could definitely use the extra exercise.
                            Maybe you'll come back here next week for some mindless, stress-relieving vandalism.
                            If what Seki says is true, you'll no longer have to worry about [i]inconveniencing[/i] him by then,
                            and you'll undoubtebly have plenty of frustration to work out on inanimate objects.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width: 170px;">Walk away</button>`;

        var tooltip = global.parser.parse(`The well doesn't interest you anymore. Now it just makes you sad.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 170px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 170px;">Draw water</button>`;

        var tooltip = global.parser.parse(`Attempt to fetch some water from the bottom of the pit.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 205px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 170px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled} style="width: 170px;">Climb down</button>`;

        var tooltip = global.parser.parse(`Scale down the rocky well wall.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 210px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 170px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }
    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var check = ctrl.misc.hasMisc(new Rope());
        var disabled = subController.has() || !check ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled} style="width: 170px;">Use rope</button>`;

        var tooltip = global.parser.parse(`Use your rope to climb down into the well.`);
        if (!check) {
            tooltip = global.parser.parse(`You don't have a rope to climb down with.`);
        }

        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 170px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 20px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildThirdChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFourthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.imageBackground.show("scenes/HamletDay2/HamletWell/img/wellbackground.png");
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        part += fourthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();
        fourthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
    };
}

var HamletWellArrivalChoice = {
    WALK: 1,
    WATER: 2,
    CLIMB: 3,
    ROPE: 4
};
