/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellClimbRelent(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellClimbUpChoice.GIVE;
    var reqController = ctrl.climbUp;
    var subController = ctrl.preContinue;
    var changeController = ctrl.climbUpRelent;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var pants = ctrl.misc.pants();
        var drank = global.kobold.history.shared.well.drankWater;
        var drowned = global.kobold.history.shared.well.drowned;
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var rope = arrivalChoice === HamletWellArrivalChoice.ROPE;
        var toReturn = `[p]
                            This is dangerous.
                            The further up you go, the more likely you'll be to [b]severely[/b] hurt yourself when you inevitably fuck up.
                            Growing ever more exhausted, you doubt it'll take long for you to [i]slip and fall[/i], or to pick another unstable rock.
                            You've already gotten lucky, and managed to prevent yourself from falling down [i]once[/i].
                            You don't want to keep testing fate.
                        [/p]
                        [p]
                            Letting out a loud, exacerbating sigh, you begin to climb back down the
                            well${wanted ? `, just like before${rope ? `, but this time without a rope` : ``}` : ``}.
                            ${!rocky ? `You've done this already, a fact that significantly boosts confidence in your climbing abilities.
                            Still, your journey is not without peril.` : `You hope you can go down the well [i]without[/i] falling this time around.
                            The shoddy cobblestone wall you're scaling isn't making this any easier for you, though.`}
                        [/p]
                        [p]
                            The earlier near-fall has made you somewhat paranoid.
                            You question every step you take, thoroughly testing every stone before grabbing it with your hand or placing your foot down upon it.
                            While being dilligent makes the entire ordeal a bit [i]safer[/i], it also complicates things.
                            Entire paths which you would have taken without a doubt before are suddenly deemed too hazardous by your frightened mind.
                            You find yourself having to [b]stretch[/b] your body a lot more than usual to be able to [b]reach[/b] [i]safer[/i] points,
                            to put your aching sense of self-preservation at ease.
                        [/p]
                        [p]
                            Despite needing to test the very limits of how far you can extend your body, you manage to make it back down to the cold water without falling down.
                            You slip back into the cold liquid, to give your aching limbs a bit of much needed rest.
                            Even if you didn't manage to escape the well, sure was one hell of a workout.
                            You hope you'll be able to make it out of here alive, so you can put your newfound flexibility to use.
                        [/p]
                        [p]
                            Right as you were starting to consider other avenues of escape, a loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
