/**
 * Arrival section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellWaterSucceed(controller, firstNext, secondNext, thirdNext) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.down;
    var changeController = ctrl.waterSucceed;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    //var firstNext = new HamletWellSwim(ctrl);
    //var secondNext = new HamletWellClimb(ctrl);
    //var thirdNext = new HamletWellHelp(ctrl);

    var firstChoice = HamletWellFallChoice.SWIM;
    var secondChoice = HamletWellFallChoice.CLIMB;
    var thirdChoice = HamletWellFallChoice.HELP;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.fell = true;
        global.kobold.history.shared.well.drowned = true;
        global.kobold.history.shared.well.drankWater = true;
        var toReturn = `[p]
                            After your depressing train of thoughts, you need something, [b]anything[/b] to take your mind off of Seki.
                            Desperately looking for a way to forget about your friend for a while, you turn to the rope disappearing into the well.
                            Drawing water might be a good way to pass the time, and honestly, you could use a refreshing drink.
                        [/p]
                        [p]
                            You grab the rope, and give it a firm [b]yank[/b].
                            It doesn't budge.
                            The bucket must be stuck on something, or maybe it's just too heavy for you to lift.
                            Determined to get some water, you dig your claws into the ground and lean back,
                            tugging at the rope with not just your arms, but your entire weight, however little that may be.
                        [/p]
                        [p]
                            Your new tactic proves to be effective!
                            After a bit of pulling, the bucket finally shoots free, causing you to fall on your behind.
                            Luckily, you're strong enough to keep the filled bucket lifted through sheer arm-strength alone.
                            You scamper to your feet without letting go of the rope, and begin to painstakingly hoist the container upwards, one tug at a time.
                        [/p]
                        [p]
                            Success!
                            After a long and arduous game of tug of war against gravity itself, a bucket of fresh well-water appears near the edge of the well.
                            You inch both your hands towards it, along the length of the rope,
                            until you can take hold of the bucket with both of your hands, to lift it out of the well proper.
                            You did it!
                            It was hard, but you've managed to draw water from the well.
                            Your reward is a bucket of fresh, cool water.
                            Now for the fun part: to drink it!
                        [/p]
                        [p]
                            You bring the rim of the bucket to your lips.
                            Opening your muzzle, you tilt both your head and the container upwards, letting the refreshing liquid [b]gush[/b] into your open maw,
                            greedily gulping it down like the exhausted lizard you are.
                            After emptying about half of the bucket, a lot of which was spilled over your chest instead of disappearing down your throat,
                            you set the considerably lighter wooden container down on the ground.
                        [/p]
                        [p]
                            Suddenly, your sight goes kind of blurry.
                            You feel woozy, and your body rocks from side to side as though you're drunk!
                            You stumble about, trying to find the edge of the well, so you can take a seat until the feeling passes.
                            While you do manage to find the rim of the watering hole, a fresh wave of drowsiness washes over you.
                            Your balance disturbed, you fall backwards, over the edge of the well,
                            tumbling head-first into pitch-black darkness before you even know what's going on.
                        [/p]
                        [p]
                            Adrenaline floods your system, seemingly counteracting the sudden onset of tiredness.
                            Panic quickly settles in.
                            You begin to [b]scream[/b] in terror, fearing for your very life.
                            You wantonly flail your limbs about, scratching and scraping the cobblestone wall surrounding you on all sides with your claws,
                            hoping to [i]latch on[/i] to something, or at least to somewhat slow your fall.
                            Your efforts are in vain.
                            In a matter of seconds, your terrified shout is cut off,
                            interrupted by a loud [b]splash[/b] as you plummet into the cold water at the bottom of the well.
                        [/p]
                        [p]
                            Frigid water rushes into your throat via your open mouth, filling your lungs long before you manage to close your maw.
                            Your descent is quickly halted by the cool liquid, doubly so as your head bumps against the ground at the very base of the well,
                            hard enough to significantly daze you.
                        [/p]
                        [p]
                            After falling, you find yourself [b]drowning[/b].
                            In your disoriented panic, you can't tell top from bottom.
                            You twist and turn in an attempt to get yourself upright, your consciousness,
                            already diminished from hitting your head, rapidly fading due to lack of air.
                            Just as you can feel life itself starting to slip away from you, one of your feet touches the muddy ground below.
                            In a last-ditch attempt at survival, with your very last ounce of power, you kick off from the submerged dirt,
                            launching you towards the surface of the water.
                        [/p]
                        [p]
                            You emerge from the ice-cold liquid, and immediately begin coughing up the watery contents of your respiratory system.
                            Your barely active brain [b]begs[/b] for air, but you can't breathe, not until you've emptied your [b]burning[/b] lungs.
                            After painfully [b]vomiting[/b] water from both your esophagus and your trachea, you can finally take a much-needed gasp of oxygen,
                            the blackness that had begun to envelop the edges of your vision slightly clearing.
                        [/p]
                        [p]
                            It's not enough.
                            You need [b]more[/b].
                            You need to [b]breathe[/b], lest this damned well become your watery grave still.
                            You hack up more water, taking deep breaths in between each coughing fit.
                            Slowly, but steadily, you recover from the harrowing ordeal you just went through,
                            your breathing stabilizing as liquid drains from your lungs.
                        [/p]
                        [p]
                            It is only after a couple of minutes of recovering, both mentally and physically, that you can breathe normally once more.
                            The damp, stale air at the bottom of the well is of poor quality, but it sure as hell beats drowning.
                            Your gently kicking legs and your arms slowly rocking along the surface of the water keep your light frame afloat.
                            The water isn't [i]that[/i] deep.
                            You figure a tall human could stand in here, but you can't.
                        [/p]
                        [p]
                            One moment you were happily enjoying the spoils of your labor, the other you felt so sick you could hardly [b]stand[/b].
                            Was it the water?
                            You're swimming in the stuff right now, and it's not effecting you at all.
                            But then again, you've already thrown up the liquid you drank.
                            Maybe it only does it when it's ingested.
                            Or perhaps it just a momentary lapse of strength.
                            Regardless, your clumsiness nearly cost you your life.
                            You didn't die, though.
                            Not yet, anyway.
                            You let out a sigh of relief, quickly followed by an annoyed groan as you tilt your head upwards,
                            and realize that you're several meters underground with no easy way up.
                        [/p]`;
        
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Dive down</button>`;

        var tooltip = global.parser.parse(`You're not worried about getting out just yet. Dive down to see what's at the bottom of the well.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Climb out</button>`;

        var tooltip = global.parser.parse(`Scale the walls to get out of this claustrophobic hole.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Call for help</button>`;

        var tooltip = global.parser.parse(`You don't think you can climb up by yourself. Maybe someone's around to help you out.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}
