/**
 * Entrance section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopEntrance(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "entranceContinueButton";

    var toFree = new SekiWorkshopFree(ctrl);
    var toBuy = new SekiWorkshopBuy(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[st]Seki's Workshop[/st]
                        [p]
                            You enter the workshop of Seki, the owl.
                            This kind old man has helped you through some tough times in the past.
                            In some ways, you consider him the father you never had.
                            On the other hand, he's more of a [i]fence[/i] that you sell stuff you've stolen to.
                            In that regard, you suppose he's somewhat of a [i]bad[/i] influence.
                        [/p]
                        [p]
                            The workshop itself is [i]dark[/i], barely illuminated.
                            Being an owl, Seki prefers pitch-blackness above all,
                            keeping just a few candles around to prevent his customers from knocking over any of the potions he's brewed.
                            As a kobold, darkness doesn't phase you.
                            Your nightvision is superb, a fact which has significantly aided your criminal career thus far.
                            You deftly manoeuvre around the various tables and displays, towards the wooden counter,
                            where you ring a small bell to summon your elderly comrade from the depths of his shop.
                        [/p]
                        [p]
                            The old man is quite the accomplished alchemist.
                            There isn't a potion he [i]doesn't[/i] know how to brew.
                            Rumor has it that the owl used to be an advisor to the single most influential person in the entire world, the Dragon Emperor himself.
                            You've never quite asked him about it, and he hasn't told you, so you figure it's one of those things that are best left unmentioned.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.entrance.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.entrance.continue();
            if (ctrl.gold() > ctrl.minBuyGold) {
                loadNextPart(toBuy);
            } else {
                loadNextPart(toFree);
            }
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiEntrance";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.arrival.continued()) {
            return "";
        }
        
        ctrl.bgm.loop();
        global.ui.applyTheme("hamlet_shop");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toFree.build();
        part += toBuy.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.arrival.continued()) {
            return;
        }

        toFree.registerListeners();
        toBuy.registerListeners();

        if (ctrl.entrance.continued()) {
            return;
        }

        registerContinueListener();
    };
}
