/**
 * Controller for the Varanar Morning Three scene.
 * @param {string} sceneId The id of the scene.
 */
function MorningThreeController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = false;
    this.nextSceneName = "MorningThree";
    this.nextFolderName = "Varanar";

    this.misc = new MiscController(id);

    this.knights = new ChangeController(id, "knight", function () {
        var dragonessRelation = global.kobold.history.shared.dragonessPrincess.relation;

        if (dragonessRelation === DragonessPrincessEnum.UNMET) {
            global.kobold.status.mental.increase(5, "Awe-inspiring knights");
        }

        if (dragonessRelation === DragonessPrincessEnum.UNHELPED) {
            global.kobold.status.mental.increase(0, "Saw dragoness");
        }

        if (dragonessRelation === DragonessPrincessEnum.HELPED) {
            global.kobold.status.mental.increase(0, "Saw dragoness");
        }

        if (dragonessRelation === DragonessPrincessEnum.SLOPPY_SECONDS) {
            global.kobold.status.mental.increase(0, "Saw dragoness");
        }

        if (dragonessRelation === DragonessPrincessEnum.SAVED) {
            global.kobold.status.mental.increase(0, "Saw dragoness");
        }

        if (dragonessRelation === DragonessPrincessEnum.RAN_AWAY) {
            var tenpaw = global.kobold.history.shared.tenPawGang.relation;
            var raped = tenpaw === TenPawGangEnum.RELUCTANT_GANGBANG || tenpaw === TenPawGangEnum.GANGRAPE;
            if (raped) {
                global.kobold.status.mental.increase(0, "Saw dragoness");
            } else {
                global.kobold.status.mental.increase(10, "Saw dragoness");
            }
        }
    }, function () {
        var dragonessRelation = global.kobold.history.shared.dragonessPrincess.relation;
        if (dragonessRelation === DragonessPrincessEnum.UNMET) {
            return global.ui.change.buildNotification([
                new Change("Knight convoy", "Sanity", +5)
            ]);
        }

        if (dragonessRelation === DragonessPrincessEnum.UNHELPED) {
            return global.ui.change.buildNotification([
                new Change("Saw dragoness again", "Sanity", +5),
                new Change("She may remember you", "Sanity", -5)
            ]);
        }

        if (dragonessRelation === DragonessPrincessEnum.HELPED) {
            return global.ui.change.buildNotification([
                new Change("Saw dragoness again", "Sanity", +5),
                new Change("She ignored you", "Sanity", -5)
            ]);
        }

        if (dragonessRelation === DragonessPrincessEnum.SLOPPY_SECONDS) {
            return global.ui.change.buildNotification([
                new Change("Saw dragoness again", "Sanity", +5),
                new Change("She may remember you", "Sanity", -5)
            ]);
        }

        if (dragonessRelation === DragonessPrincessEnum.SAVED) {
            return global.ui.change.buildNotification([
                new Change("Saw dragoness again", "Sanity", +5),
                new Change("She ignored you", "Sanity", -5)
            ]);
        }

        if (dragonessRelation === DragonessPrincessEnum.RAN_AWAY) {
            var tenpaw = global.kobold.history.shared.tenPawGang.relation;
            var raped = tenpaw === TenPawGangEnum.RELUCTANT_GANGBANG || tenpaw === TenPawGangEnum.GANGRAPE;
            if (raped) {
                return global.ui.change.buildNotification([
                    new Change("Saw dragoness again", "Sanity", +5),
                    new Change("Bad memories", "Sanity", -5)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Saw dragoness again", "Sanity", +5),
                    new Change("Good memories", "Sanity", +5)
                ]);
            }
        }
    });

    this.eggs = new ChoiceController(id, "eggs");

    this.thievery = new ChangeController(id, "thievery", function () {
        global.kobold.status.mental.increase(5, "Stopped thief");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stopped thief", "Sanity", +5)
        ]);
    });

    this.keepEgg = new ChangeController(id, "keepEgg", function () {
        global.kobold.inventory.equipment.wear(new RottenEgg());
        global.kobold.status.mental.decrease(0, "Guard-sanctioned gangrape");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Bullied thief", "Sanity", +5),
            new Change("Poetic justice?", "Sanity", +5),
            new Change("Guard-sanctioned gangrape", "Sanity", -5),
            new Change("Fear of getting caught", "Sanity", -5),
            new Change("Kept egg", global.kobold.inventory.createItemWithTooltip(new RottenEgg(), true), +1)
        ]);
    });

    this.returnEgg = new ChangeController(id, "returnEgg", function () {
        global.kobold.status.mental.decrease(0, "Guard-sanctioned gangrape");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Moral highground", "Sanity", +5),
            new Change("Poetic justice?", "Sanity", +5),
            new Change("Guard-sanctioned gangrape", "Sanity", -5),
            new Change("Fear of getting caught", "Sanity", -5)
        ]);
    });

    this.throwEgg = new ChangeController(id, "throwEgg", function () {
        global.kobold.status.mental.decrease(0, "Guard-sanctioned gangrape");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Punished thief", "Sanity", +5),
            new Change("Poetic justice?", "Sanity", +5),
            new Change("Guard-sanctioned gangrape", "Sanity", -5),
            new Change("Fear of getting caught", "Sanity", -5)
        ]);
    });

    this.proposition = new ChangeController(id, "proposition", function () {
        if (that.eggs.get() === MorningThreeEggsChoice.ONE) {
            global.kobold.status.mental.increase(5, "Throwing an egg");
        } else {
            global.kobold.status.mental.increase(10, "Throwing eggs");
        }
    }, function () {
        if (that.eggs.get() === MorningThreeEggsChoice.ONE) {
            return global.ui.change.buildNotification([
                new Change("Threw an egg", "Sanity", +2),
                new Change("Had fun", "Sanity", +3)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Threw first egg", "Sanity", +2),
                new Change("Threw second egg", "Sanity", +5),
                new Change("Had fun", "Sanity", +3)
            ]);
        }
    });

    this.propositionAgree = new ChangeController(id, "propositionAgree", function () {
        global.kobold.status.mental.increase(5, "Imminent sex");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Imminent sex", "Sanity", +5)
        ]);
    });

    this.declineSex = new ChangeController(id, "declineSex", function () {
        global.kobold.status.mental.decrease(3, "Friend disappeared");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Threw first egg", "Sanity", +2),
            new Change("Threw second egg", "Sanity", +5),
            new Change("Made friend sad", "Sanity", -5),
            new Change("Friend disappeared", "Sanity", -5)
        ]);
    });

    this.maleSex = new ChangeController(id, "maleSex", function () {
        global.kobold.body.dickVirgin = false;
        var dick = that.misc.dick();
        if (dick < SizeEnum.AVERAGE) {
            global.kobold.status.mental.increase(20, "Had sex");
            global.kobold.status.stamina.decrease(5, "Had sex");
            global.kobold.status.exertion.increase(25, "Had sex");
        } else if (dick < SizeEnum.LARGER) {
            global.kobold.status.mental.increase(25, "Had sex");
            global.kobold.status.stamina.decrease(10, "Had sex");
            global.kobold.status.exertion.increase(30, "Had sex");
        } else {
            global.kobold.status.mental.increase(25, "Got a blowjob");
            global.kobold.status.exertion.increase(20, "Got a blowjob");
        }
    }, function () {
        var dick = that.misc.dick();
        if (dick < SizeEnum.AVERAGE) {
            return global.ui.change.buildNotification([
                new Change("Sex", "Sanity", +15),
                new Change("Came", "Sanity", +5),
                new Change("Fucking", "Stamina", -5),
                new Change("Sensual fucking", "Sexual exhaustion", +20, true),
                new Change("Orgasm", "Sexual exhaustion", +5, true)
            ]);
        } else if (dick < SizeEnum.LARGER) {
            return global.ui.change.buildNotification([
                new Change("Sex", "Sanity", +15),
                new Change("Came", "Sanity", +5),
                new Change("Fucked partner silly", "Sanity", +5),
                new Change("Intense sex", "Stamina", -10),
                new Change("Intense fucking", "Sexual exhaustion", +25, true),
                new Change("Orgasm", "Sexual exhaustion", +5, true)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Impressed partner", "Sanity", +5),
                new Change("Blowjob", "Sanity", +15),
                new Change("Came", "Sanity", +5),
                new Change("Got sucked off", "Sexual exhaustion", +15, true),
                new Change("Orgasm", "Sexual exhaustion", +5, true)
            ]);
        }
    });

    this.femaleForeplay = new ChoiceController(id, "femaleForeplay");

    this.femaleOral = new ChoiceController(id, "femaleOral");

    this.youFirst = new ChangeController(id, "youFirst", function () {
        global.kobold.status.mental.increase(15, "Getting eaten out");
        global.kobold.status.exertion.increase(20, "Getting eaten out");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Got eaten out", "Sanity", +10),
            new Change("Reached climax", "Sanity", +5),
            new Change("Got eaten out", "Sexual exhaustion", +15, true),
            new Change("Orgasm", "Sexual exhaustion", +5, true)
        ]);
    });

    this.himFirst = new ChangeController(id, "himFirst", function () {
        global.kobold.body.oralVirgin = false;
        global.kobold.status.mental.increase(10, "Giving a good blowjob");
        global.kobold.status.stamina.decrease(5, "Giving a blowjob");
        global.kobold.status.exertion.increase(15, "Giving a blowjob");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Gave a good blowjob", "Sanity", +5),
            new Change("About to get eaten out", "Sanity", +5),
            new Change("Gave a blowjob", "Stamina", -5),
            new Change("Gave a blowjob", "Sexual exhaustion", +15, true)
        ]);
    });


    this.femaleSex = new ChoiceController(id, "femaleSex");

    this.femaleOutside = new ChangeController(id, "femaleOutside", function () {
        global.kobold.body.vaginalVirgin = false;
        if (that.misc.luck() > 5) {
            global.kobold.status.mental.increase(25, "Sex with the cyan kobold");
            global.kobold.status.stamina.decrease(5, "Sex with the cyan kobold");
            global.kobold.status.exertion.increase(30, "Sex with the cyan kobold");
        } else {
            global.kobold.status.mental.increase(5, "Sex with the cyan kobold");
            global.kobold.status.stamina.decrease(5, "Sex with the cyan kobold");
            global.kobold.status.exertion.increase(30, "Sex with the cyan kobold");
        }
    }, function () {
        if (that.misc.luck() > 5) {
            return global.ui.change.buildNotification([
                new Change("Got fucked", "Sanity", +10),
                new Change("Reached climax", "Sanity", +5),
                new Change("Not impregnated", "Sanity", +10),
                new Change("Rode cock", "Stamina", -5),
                new Change("Intensive sex", "Sexual exhaustion", +25, true),
                new Change("Orgasm", "Sexual exhaustion", +5, true)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Got fucked", "Sanity", +10),
                new Change("Reached climax", "Sanity", +5),
                new Change("Impregnated?", "Sanity", -10),
                new Change("Rode cock", "Stamina", -5),
                new Change("Intensive sex", "Sexual exhaustion", +25, true),
                new Change("Orgasm", "Sexual exhaustion", +5, true)
            ]);
        }
    });

    this.femaleInside = new ChangeController(id, "femaleInside", function () {
        global.kobold.body.vaginalVirgin = false;
        global.kobold.status.mental.increase(25, "Sex with the cyan kobold");
        global.kobold.status.exertion.increase(30, "Sex with the cyan kobold");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Got fucked", "Sanity", +10),
            new Change("Reached climax", "Sanity", +5),
            new Change("Impregnated?", "Sanity", +10),
            new Change("Intensive sex", "Sexual exhaustion", +25, true),
            new Change("Orgasm", "Sexual exhaustion", +5, true)
        ]);
    });

    this.preBucket = new ContinueController(id, "preBucket");

    this.bucket = new ChangeController(id, "bucket", function () {
        if (that.femaleOral.get() === MorningThreeFemaleOralChoice.HIM) {
            global.kobold.status.physical.increase(5, "Refreshing water");
            global.kobold.status.mental.decrease(10, "Denied orgasm");
            global.kobold.status.stamina.decrease(5, "Ran from alley");
            global.kobold.status.exertion.decrease(5, "Refreshing water");
        } else {
            global.kobold.status.physical.increase(5, "Refreshing water");
            global.kobold.status.mental.decrease(5, "Intimacy interrupted");
            global.kobold.status.stamina.decrease(5, "Ran from alley");
            global.kobold.status.exertion.decrease(5, "Refreshing water");
        }
    }, function () {
        if (that.femaleOral.get() === MorningThreeFemaleOralChoice.HIM) {
            return global.ui.change.buildNotification([
                new Change("Refreshing water", "Health", +5),
                new Change("Intimacy interrupted", "Sanity", -5),
                new Change("Denied orgasm", "Sanity", -5),
                new Change("Ran", "Stamina", -5),
                new Change("Refreshing water", "Sexual exhaustion", -5, true)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Refreshing water", "Health", +5),
                new Change("Intimacy interrupted", "Sanity", -5),
                new Change("Ran", "Stamina", -5),
                new Change("Refreshing water", "Sexual exhaustion", -5, true)
            ]);
        }
    });

    this.preContinue = new ContinueController(id, "preContinue");

    this.sad = new ChangeController(id, "sad", function () {
        global.kobold.status.mental.decrease(15, "Heartbroken");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Heartbroken", "Sanity", -15)
        ]);
    });

    this.troubling = new ChangeController(id, "troubling", function () {
        global.kobold.status.mental.decrease(5, "Guard-sanctioned gangrape");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Poetic justice?", "Sanity", +5),
            new Change("Guard-sanctioned gangrape", "Sanity", -5),
            new Change("Fear of getting caught", "Sanity", -5)
        ]);
    });

    this.robbed = new ChangeController(id, "robbed", function change() {
        var coins = global.kobold.inventory.coins;
        if (coins >= 5) {
            global.kobold.inventory.coins = coins - 5;
        } else {
            global.kobold.inventory.coins = 0;
        }
        global.kobold.status.mental.increase(5, "Friend disappeared");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Threw first egg", "Sanity", +2),
            new Change("Threw second egg", "Sanity", +5),
            new Change("Friend disappeared", "Sanity", -2)
        ]);
    });

    this.declineEgg = new ChangeController(id, "declineEgg", function () {
        global.kobold.status.mental.decrease(10, "Guard-sanctioned gangrape");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Scared off new friend", "Sanity", -5),
            new Change("Poetic justice?", "Sanity", +5),
            new Change("Guard-sanctioned gangrape", "Sanity", -5),
            new Change("Fear of getting caught", "Sanity", -5)
        ]);
    });
    
    this.splashSound = new AudioController(id, "res/audio/splash.mp3", 50);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}
